class StutteredPrimes {
	
	/** Prints out the stutter of all primes
	    from 2 up to the given command line argument
	    interpreted as an integer, 10 to a line.
	 */

	public static void main(String[] args) {

		/* In lecture 2, we also used hijacked our main function
           to perform incremnetal testing. This is not the best way 
           to do things and we'll learn a better way in lecture 3

           Example of an incremental test:
           System.out.println(stutter(Integer.parseInt(args[0])));  

           This ensures that stutter works.

           But hijacking main really isn't the best idea.
           */
		

		printStutteredPrimes(Integer.parseInt(args[0]));

	}

	//could do public, but we won't talk about this today

	/** Prints out the stutter of all primes
	    from 2 up to limit, 10 to a line.
	 */
	private static void printStutteredPrimes(int limit) {
		/*{
			for each number x, between 2 and limit,
			if isPrime(x), print stutter(x)		
		
		}*/
	}

	/** Returns true iff x is prime */
	private static boolean isPrime(int x) {
		/** A number x is prime if:
		    1. It is positive. 
		    2. If it has no factors between 2
		       and itself exclusive.
		*/
		//guards or guarded commands
		if (x <= 0) {
			return false;
		}

		//has factor greater than or equal to 2
		//! -- means NOT 
		return !hasFactorGEQk(x, 2);		
	}

	/** Returns true if there is some factor of x
	    between k and x exclusive.

	    the putative factor f has the property
	    k <= f < x

	  */
	private static boolean hasFactorGEQk(int x, int k) {
		if (k >= x)
			return false;
		if (x % k == 0) /*k is a factor of x */
			return true;
		/* just to need to check that there is no
		   factor between k+1 and x exclusive */
		return hasFactorGEQk(x, k+1);
	}

	/** Returns the stutter of x, e.g. stutteR(512)
	  * is 551122 */

	private static int stutter(int x) {
		if (x < 10)
			return 11*x;

		int lastDigit = x % 10;
		int topDigits = x / 10; 

		return stutter(lastDigit) + 100 * stutter(topDigits);
	
	}
}